/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <assert.h>
#include <limits.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  int c;
  char *optString = "hvsEb:";

  args = (Args *)emalloc(sizeof(Args));
  args->h = 0;
  args->v = 0;
  args->b = DEFAULT_B;
  args->e = 0;
  args->E = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'b':                           /* buffer size */
      args->b = atoi(optarg);
      break;
    case 's':                           /* treat sequences separately */
      args->s = 1;
      break;
    case 'E':
      args->E = 1;
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  return args;
}


void printUsage(char *version){
  printf("Purpose: count characters in FASTA sequence files\n");
  printf("Usage: cchar [options] [inputFiles]\n");
  printf("Options:\n");
  printf("\t[-s count sequences separately; default: lump individual sequences]\n");
  printf("\t[-E exact count; default: \"general\" formatting]\n");
  printf("\t[-b <NUM> buffer size; default: %d]\n", DEFAULT_B);
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("cchar %s\n",version);
  printf("Written by Bernhard Haubold\n");
  printf("Distributed under the GNU General Public License\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
